@@ -24,7 +24,6 @@ class TestBasicAssertions(unittest.TestCase):
             assertBigO(max_function, input_generator, Quadratic)
 
     def test_quadratic_complexity(self):
-        from time import sleep
         def bad_max_function(number_list):
             max_ = 0
             for el in number_list:
@@ -32,8 +31,8 @@ class TestBasicAssertions(unittest.TestCase):
                     max_ = el
 
                 # To bump the time complexity to n^2
-                for le in number_list:
-                    max_ = max_
+                for el in number_list:
+                    pass
 
             return max_
 
@@ -41,7 +40,12 @@ class TestBasicAssertions(unittest.TestCase):
             return list(range(numbers))
 
         with self.assertRaisesRegex(WrongTimeComplexity, "Expected 'Linear' but fitted time complexity is 'Quadratic'"):
-            assertBigO(bad_max_function, input_generator, Linear, timer_options={ "minimum_n": 100, "maximum_n": 10000, "n_count": 10})
+            assertBigO(
+                bad_max_function,
+                input_generator,
+                Linear,
+                timer_options={"minimum_n": 100, "maximum_n": 1000, "n_count": 10},
+            )
 
 
 if __name__ == "__main__":
